@@ -16,16 +16,14 @@
 
 #include <KStandardAction>
 #include <KStringHandler>
+#include <KPluginMetaData>
 #include <KLocalizedString>
+#include <KPluginMetaData>
 #include <QAction>
 #include <QDateTime>
 
 #include <Plasma/PluginLoader>
 
-#ifdef FOUND_SOPRANO
-#include <Soprano/Node>
-Q_DECLARE_METATYPE(Soprano::Node)
-#endif // FOUND_SOPRANO
 Q_DECLARE_METATYPE(Plasma::DataEngine::Data)
 
 #include "modelviewer.h"
@@ -40,9 +38,6 @@ EngineExplorer::EngineExplorer(QWidget* parent)
       m_expandButton(new QPushButton(i18n("Expand All"), this)),
       m_collapseButton(new QPushButton(i18n("Collapse All"), this))
 {
-#ifdef FOUND_SOPRANO
-    (void) qRegisterMetaType<Soprano::Node>();
-#endif
     setWindowTitle(i18n("Plasma Engine Explorer"));
     QWidget* mainWidget = new QWidget(this);
 
@@ -145,11 +140,19 @@ void EngineExplorer::dataUpdated(const QString& source, const Plasma::DataEngine
 void EngineExplorer::listEngines()
 {
     m_engines->clear();
-    KPluginInfo::List engines = m_engineManager->listDataEngineInfo(m_app);
-    std::sort(engines.begin(), engines.end());
+    QVector<KPluginMetaData> engines = m_engineManager->listDataEngineMetaData(m_app);
+    std::sort(engines.begin(), engines.end(), [](auto lhs, auto rhs) {
+        if (lhs.category() < rhs.category()) {
+            return true;
+        }
+        if (lhs.category() == rhs.category()) {
+            return lhs.name() < rhs.name();
+        }
+        return false;
+    });
 
-    foreach (const KPluginInfo engine, engines) {
-        m_engines->addItem(QIcon::fromTheme(engine.icon()), engine.pluginName());
+    for (const KPluginMetaData &engine : qAsConst(engines)) {
+        m_engines->addItem(QIcon::fromTheme(engine.iconName()), engine.pluginId());
     }
 
     m_engines->setCurrentIndex(-1);
@@ -403,18 +406,6 @@ QString EngineExplorer::convertToString(const QVariant &value)
             return QString("%1").arg(value.toTime().toString());
         }
         default: {
-#ifdef FOUND_SOPRANO
-            if (QLatin1String(value.typeName()) == "Soprano::Node") {
-                Soprano::Node node = value.value<Soprano::Node>();
-                if (node.isLiteral()) {
-                    return convertToString(node.literal().variant());
-                } else if (node.isResource()) {
-                    return node.uri().toString();
-                } else if (node.isBlank()) {
-                    return QString("_:%1").arg(node.identifier());
-                }
-            }
-#endif
             if (QLatin1String(value.typeName()) == "QDateTime") {
                 return QString("%1").arg(value.value<QDateTime>().toString());
             }
@@ -487,7 +478,7 @@ int EngineExplorer::showData(QStandardItem* parent, Plasma::DataEngine::Data dat
 
 void EngineExplorer::updateTitle()
 {
-    if (!m_engine || !m_engine->pluginInfo().isValid()) {
+    if (!m_engine || !m_engine->metadata().isValid()) {
         m_title->setIcon(QIcon::fromTheme("plasma"));
         m_title->setText(i18n("Plasma DataEngine Explorer"));
         return;
@@ -495,13 +486,13 @@ void EngineExplorer::updateTitle()
 
     m_title->setText(ki18ncp("The name of the engine followed by the number of data sources",
                              "%1 Engine - 1 data source", "%1 Engine - %2 data sources")
-                              .subs(KStringHandler::capwords(m_engine->pluginInfo().name()))
+                              .subs(KStringHandler::capwords(m_engine->metadata().name()))
                               .subs(m_sourceCount).toString());
 
-    if (m_engine->pluginInfo().icon().isEmpty()) {
+    if (m_engine->metadata().iconName().isEmpty()) {
         m_title->setIcon(QIcon::fromTheme("plasma"));
     } else {
-        m_title->setIcon(QIcon::fromTheme(m_engine->pluginInfo().icon()));
+        m_title->setIcon(QIcon::fromTheme(m_engine->metadata().iconName()));
     }
 }
 
